Unit TestGlobalOptions;

Interface

Uses
  TestFramework,
  GlobalOptions,
  ToolsAPI;

Type
  //
  // Test Class for the TProjectOptions Class Methods.
  //
  TestTProjectOptions = Class(TTestCase)
  Strict Private
  Public
    Procedure SetUp; Override;
    Procedure TearDown; Override;
  Published
    Procedure TestAddZipFiles;
    Procedure TestBasePath;
    Procedure TestBuild;
    Procedure TestCompileRes;
    Procedure TestCopyVerInfo;
    Procedure TestEnableZipping;
    Procedure TestExcPatterns;
    Procedure TestIncITHVerInfo;
    Procedure TestIncOnCompile;
    Procedure TestIncResInProj;
    Procedure TestINIFile;
    Procedure TestMajor;
    Procedure TestMinor;
    Procedure TestRelease;
    Procedure TestResExtExc;
    Procedure TestResourceName;
    Procedure TestVerInfo;
    Procedure TestWarnAfter;
    Procedure TestWarnBefore;
    Procedure TestZipName;
    Procedure TestUpdateVersionNumbers;
  End;

  //
  // Test Class for the TGlobalOptions Class Methods.
  //
  TestTGlobalOptions = Class(TTestCase)
  Strict Private
  Public
    Procedure SetUp; Override;
    Procedure TearDown; Override;
  Published
    Procedure TestProjectOptions;
    Procedure TestSave;
    Procedure TestAutoScrollMessages;
    Procedure TestClearMessages;
    Procedure TestFontColour;
    Procedure TestFontName;
    Procedure TestFontStyles;
    Procedure TestGroupMessages;
    Procedure TestINIFileName;
    Procedure TestProjectGroupOps_NewProject;
    Procedure TestProjectGroupOps_OldProject;
    Procedure TestSwitchToMessages;
    Procedure TestZipEXE;
    Procedure TestZipParameters;
  End;

Implementation

Uses
  SysUtils,
  Classes,
  DGHLibrary,
  Graphics;

{$REGION 'TProjectOptions Tests'}
//
// Test Methods for Class TProjectOptions.
//
Procedure TestTProjectOptions.Setup;

Begin
End;

Procedure TestTProjectOptions.TearDown;

Begin
End;

Procedure TestTProjectOptions.TestAddZipFiles;

Var
  sl : TStringList;
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  sl := TStringList.Create;
  Try
    FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
    Try
      sl.Assign(FProjectOps.AddZipFiles);
      CheckEquals(0, sl.Count);
      sl.Clear;
      sl.Add('D:\Path\File*.*');
      sl.Add('E:\MyPath\MyFile*.gif');
      FProjectOps.AddZipFiles.Assign(sl);
      sl.Assign(FProjectOps.AddZipFiles);
      CheckEquals(2, sl.Count);
      CheckEquals('D:\Path\File*.*', sl[0]);
      CheckEquals('E:\MyPath\MyFile*.gif', sl[1]);
    Finally
      FProjectOps.Free;
    End;
    FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
    Try
      sl.Assign(FProjectOps.AddZipFiles);
      CheckEquals(2, sl.Count);
      CheckEquals('D:\Path\File*.*', sl[0]);
      CheckEquals('E:\MyPath\MyFile*.gif', sl[1]);
    Finally
      FProjectOps.Free;
    End;
    FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
    Try
      sl.Assign(FProjectOps.AddZipFiles);
      sl.Delete(0);
      FProjectOps.AddZipFiles.Assign(sl);
      sl.Assign(FProjectOps.AddZipFiles);
      CheckEquals(1, sl.Count);
      CheckEquals('E:\MyPath\MyFile*.gif', sl[0]);
    Finally
      FProjectOps.Free;
    End;
    FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
    Try
      sl.Assign(FProjectOps.AddZipFiles);
      CheckEquals(1, sl.Count);
      CheckEquals('E:\MyPath\MyFile*.gif', sl[0]);
    Finally
      FProjectOps.Free;
    End;
  Finally
    sl.Free;
  End;
End;

Procedure TestTProjectOptions.TestBasePath;

Var
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(ExtractFilePath(ParamStr(0)), FProjectOps.BasePath, 'Default BasePath');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.BasePath := 'C:\HoylD\';
    CheckEquals('C:\HoylD\', FProjectOps.BasePath, 'BasePath First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TPRojectStub.Create);
  Try
    CheckEquals('C:\HoylD\', FProjectOps.BasePath, 'BasePath on Reload');
  Finally
    FProjectOps.Free;
  End;
End;

Procedure TestTProjectOptions.TestBuild;

Var
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(0, FProjectOps.Build, 'Default Build');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.Build := 123;
    CheckEquals(123, FProjectOps.Build, 'Build First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(123, FProjectOps.Build, 'Build on Reload');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.Build := 321;
    CheckEquals(321, FProjectOps.Build, 'Build First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(321, FProjectOps.Build, 'Build on Reload');
  Finally
    FProjectOps.Free;
  End;
End;

Procedure TestTProjectOptions.TestCompileRes;

Var
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(False, FProjectOps.CompileRes, 'Default CompileRes');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.CompileRes := True;
    CheckEquals(True, FProjectOps.CompileRes, 'CompileRes First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(True, FProjectOps.CompileRes, 'CompileRes on Reload');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.CompileRes := False;
    CheckEquals(False, FProjectOps.CompileRes, 'CompileRes Second Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(False, FProjectOps.CompileRes, 'CompileRes on Reload');
  Finally
    FProjectOps.Free;
  End;
End;

Procedure TestTProjectOptions.TestCopyVerInfo;

Var
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals('', FProjectOps.CopyVerInfo, 'Default CopyVerInfo');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.CopyVerInfo := 'C:\Windows\Notepad.exe';
    CheckEquals('C:\Windows\Notepad.exe', FProjectOps.CopyVerInfo, 'CopyVerInfo First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals('C:\Windows\Notepad.exe', FProjectOps.CopyVerInfo, 'CopyVerInfo on Reload');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.CopyVerInfo := 'C:\Windows\WinPad.exe';
    CheckEquals('C:\Windows\WinPad.exe', FProjectOps.CopyVerInfo, 'CopyVerInfo Second Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals('C:\Windows\WinPad.exe', FProjectOps.CopyVerInfo, 'CopyVerInfo on Reload');
  Finally
    FProjectOps.Free;
  End;
End;

Procedure TestTProjectOptions.TestEnableZipping;

Var
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(False, FProjectOps.EnableZipping, 'Default EnableZipping');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.EnableZipping := True;
    CheckEquals(True, FProjectOps.EnableZipping, 'EnableZipping First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(True, FProjectOps.EnableZipping, 'EnableZipping on Reload');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.EnableZipping := False;
    CheckEquals(False, FProjectOps.EnableZipping, 'EnableZipping Second Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(False, FProjectOps.EnableZipping, 'EnableZipping on Reload');
  Finally
    FProjectOps.Free;
  End;
End;

Procedure TestTProjectOptions.TestExcPatterns;

Var
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals('', FProjectOps.ExcPatterns, 'Default ExcPatterns');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.ExcPatterns := 'Qwerty*.*'#13#10'Ytrewq.bmp';
    CheckEquals('Qwerty*.*'#13#10'Ytrewq.bmp', FProjectOps.ExcPatterns, 'ExcPatterns First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals('Qwerty*.*'#13#10'Ytrewq.bmp', FProjectOps.ExcPatterns, 'ExcPatterns on Reload');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.ExcPatterns := 'Qwerty.*'#13#10'Source\Property.*'#13#10'Images\*.bmp';
    CheckEquals('Qwerty.*'#13#10'Source\Property.*'#13#10'Images\*.bmp', FProjectOps.ExcPatterns, 'ExcPatterns Second Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals('Qwerty.*'#13#10'Source\Property.*'#13#10'Images\*.bmp', FProjectOps.ExcPatterns, 'ExcPatterns on Reload');
  Finally
    FProjectOps.Free;
  End;
End;

Procedure TestTProjectOptions.TestIncITHVerInfo;

Var
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(False, FProjectOps.IncITHVerInfo, 'Default IncITHVerInfo');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.IncITHVerInfo := True;
    CheckEquals(True, FProjectOps.IncITHVerInfo, 'IncITHVerInfo First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(True, FProjectOps.IncITHVerInfo, 'IncITHVerInfo on Reload');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.IncITHVerInfo := False;
    CheckEquals(False, FProjectOps.IncITHVerInfo, 'IncITHVerInfo Second Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(False, FProjectOps.IncITHVerInfo, 'IncITHVerInfo on Reload');
  Finally
    FProjectOps.Free;
  End;
End;

Procedure TestTProjectOptions.TestIncOnCompile;

Var
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(False, FProjectOps.IncOnCompile, 'Default IncOnCompile');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.IncOnCompile := True;
    CheckEquals(True, FProjectOps.IncOnCompile, 'IncOnCompile First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(True, FProjectOps.IncOnCompile, 'IncOnCompile on Reload');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.IncOnCompile := False;
    CheckEquals(False, FProjectOps.IncOnCompile, 'IncOnCompile Second Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(False, FProjectOps.IncOnCompile, 'IncOnCompile on Reload');
  Finally
    FProjectOps.Free;
  End;
End;

Procedure TestTProjectOptions.TestIncResInProj;

Var
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(False, FProjectOps.IncResInProj, 'Default IncResInProj');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.IncResInProj := True;
    CheckEquals(True, FProjectOps.IncResInProj, 'IncResInProj First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(True, FProjectOps.IncResInProj, 'IncResInProj on Reload');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.IncResInProj := False;
    CheckEquals(False, FProjectOps.IncResInProj, 'IncResInProj Second Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(False, FProjectOps.IncResInProj, 'IncResInProj on Reload');
  Finally
    FProjectOps.Free;
  End;
End;

Procedure TestTProjectOptions.TestINIFile;

Var
  FProjectOps : TProjectOptions;

Begin
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(GetProjectINIFileName, FProjectOps.INIFile.FileName, 'INIFile');
  Finally
    FProjectOps.Free;
  End;
End;

Procedure TestTProjectOptions.TestMajor;

Var
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(1, FProjectOps.Major, 'Default Major');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.Major := 123;
    CheckEquals(123, FProjectOps.Major, 'Major First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(123, FProjectOps.Major, 'Major on Reload');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.Major := 321;
    CheckEquals(321, FProjectOps.Major, 'Major First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(321, FProjectOps.Major, 'Major on Reload');
  Finally
    FProjectOps.Free;
  End;
End;

Procedure TestTProjectOptions.TestMinor;

Var
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(0, FProjectOps.Minor, 'Default Minor');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.Minor := 123;
    CheckEquals(123, FProjectOps.Minor, 'Minor First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(123, FProjectOps.Minor, 'Minor on Reload');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.Minor := 321;
    CheckEquals(321, FProjectOps.Minor, 'Minor First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(321, FProjectOps.Minor, 'Minor on Reload');
  Finally
    FProjectOps.Free;
  End;
End;

Procedure TestTProjectOptions.TestRelease;

Var
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(0, FProjectOps.Release, 'Default Release');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.Release := 123;
    CheckEquals(123, FProjectOps.Release, 'Release First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(123, FProjectOps.Release, 'Release on Reload');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.Release := 321;
    CheckEquals(321, FProjectOps.Release, 'Release First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(321, FProjectOps.Release, 'Release on Reload');
  Finally
    FProjectOps.Free;
  End;
End;

Procedure TestTProjectOptions.TestResExtExc;

Var
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals('.dcr', FProjectOps.ResExtExc, 'Default ResExtExc');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.ResExtExc := '.dcr;.res';
    CheckEquals('.dcr;.res', FProjectOps.ResExtExc, 'ResExtExc First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals('.dcr;.res', FProjectOps.ResExtExc, 'ResExtExc on Reload');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.ResExtExc := '.res';
    CheckEquals('.res', FProjectOps.ResExtExc, 'ResExtExc Second Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals('.res', FProjectOps.ResExtExc, 'ResExtExc on Reload');
  Finally
    FProjectOps.Free;
  End;
End;

Procedure TestTProjectOptions.TestResourceName;

Var
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals('ITHelperVersionInfo', FProjectOps.ResourceName, 'Default ResourceName');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.ResourceName := 'MyApplicationVerInfo';
    CheckEquals('MyApplicationVerInfo', FProjectOps.ResourceName, 'ResourceName First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals('MyApplicationVerInfo', FProjectOps.ResourceName, 'ResourceName on Reload');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.ResourceName := 'DLLs\MyApplicationVerInfo';
    CheckEquals('DLLs\MyApplicationVerInfo', FProjectOps.ResourceName, 'ResourceName Second Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals('DLLs\MyApplicationVerInfo', FProjectOps.ResourceName, 'ResourceName on Reload');
  Finally
    FProjectOps.Free;
  End;
End;

Procedure TestTProjectOptions.TestUpdateVersionNumbers;

Var
  sl : TStringList;
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  sl := TStringList.Create;
  Try
    FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
    Try
      FProjectOps.Major := 2;
      FProjectOps.Minor := 3;
      FProjectOps.Release := 4;
      FProjectOps.Build := 5;
      sl.Assign(FProjectOps.VerInfo);
      CheckEquals('2.3.4.5', sl.Values['FileVersion']);
    Finally
      FProjectOps.Free;
    End;
    FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
    Try
      sl.Assign(FProjectOps.VerInfo);
      CheckEquals('2.3.4.5', sl.Values['FileVersion']);
      FProjectOps.Build := 123;
      sl.Assign(FProjectOps.VerInfo);
      CheckEquals('2.3.4.123', sl.Values['FileVersion']);
    Finally
      FProjectOps.Free;
    End;
    FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
    Try
      sl.Assign(FProjectOps.VerInfo);
      CheckEquals('2.3.4.123', sl.Values['FileVersion']);
    Finally
      FProjectOps.Free;
    End;
  Finally
    sl.Free;
  End;
End;

Procedure TestTProjectOptions.TestVerInfo;

Var
  sl : TStringList;
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  sl := TStringList.Create;
  Try
    FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
    Try
      sl.Assign(FProjectOps.VerInfo);
      CheckEquals(10, sl.Count);
      CheckEquals('CompanyName=', sl[0]);
      CheckEquals('FileDescription=', sl[1]);
      CheckEquals('FileVersion=1.0.0.0', sl[2]);
      CheckEquals('InternalName=', sl[3]);
      CheckEquals('LegalCopyright=', sl[4]);
      CheckEquals('LegalTrademarks=', sl[5]);
      CheckEquals('OriginalFilename=', sl[6]);
      CheckEquals('ProductName=', sl[7]);
      CheckEquals('ProductVersion=1.0', sl[8]);
      CheckEquals('Comments=', sl[9]);
      sl.Values['CompanyName'] := 'Season''s Fall';
      sl.Values['FileDescription'] := 'TestProject';
      sl.Values['FileVersion'] := '2.3.4.5';
      sl.Values['InternalName'] := 'TestProject';
      sl.Values['LegalCopyright'] := 'Season''s Fall';
      sl.Values['LegalTrademarks'] := 'Season''s Fall';
      sl.Values['OriginalFilename'] := 'TestProject';
      sl.Values['ProductName'] := 'TestProject';
      sl.Values['ProductVersion'] := '2.3';
      sl.Values['Comments'] := 'My COmment!';
      FProjectOps.VerInfo.Assign(sl);
    Finally
      FProjectOps.Free;
    End;
    FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
    Try
      sl.Assign(FProjectOps.VerInfo);
      CheckEquals(10, sl.Count);
      CheckEquals('CompanyName=Season''s Fall', sl[0]);
      CheckEquals('FileDescription=TestProject', sl[1]);
      CheckEquals('FileVersion=2.3.4.5', sl[2]);
      CheckEquals('InternalName=TestProject', sl[3]);
      CheckEquals('LegalCopyright=Season''s Fall', sl[4]);
      CheckEquals('LegalTrademarks=Season''s Fall', sl[5]);
      CheckEquals('OriginalFilename=TestProject', sl[6]);
      CheckEquals('ProductName=TestProject', sl[7]);
      CheckEquals('ProductVersion=2.3', sl[8]);
      CheckEquals('Comments=My COmment!', sl[9]);
      FProjectOps.VerInfo.Assign(sl);
    Finally
      FProjectOps.Free;
    End;
    FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
    Try
      sl.Assign(FProjectOps.VerInfo);
      sl.Add('DGHKey=Hello');
      sl.Delete(5);
      sl.Delete(1);
      FProjectOps.VerInfo.Assign(sl);
    Finally
      FProjectOps.Free;
    End;
    FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
    Try
      sl.Assign(FProjectOps.VerInfo);
      CheckEquals(9, sl.Count);
      CheckEquals('CompanyName=Season''s Fall', sl[0]);
      CheckEquals('FileVersion=2.3.4.5', sl[1]);
      CheckEquals('InternalName=TestProject', sl[2]);
      CheckEquals('LegalCopyright=Season''s Fall', sl[3]);
      CheckEquals('OriginalFilename=TestProject', sl[4]);
      CheckEquals('ProductName=TestProject', sl[5]);
      CheckEquals('ProductVersion=2.3', sl[6]);
      CheckEquals('Comments=My COmment!', sl[7]);
      CheckEquals('DGHKey=Hello', sl[8]);
      FProjectOps.VerInfo.Assign(sl);
    Finally
      FProjectOps.Free;
    End;
  Finally
    sl.Free;
  End;
End;

Procedure TestTProjectOptions.TestWarnAfter;

Var
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(True, FProjectOps.WarnAfter, 'Default WarnAfter');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.WarnAfter := False;
    CheckEquals(False, FProjectOps.WarnAfter, 'WarnAfter First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(False, FProjectOps.WarnAfter, 'WarnAfter on Reload');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.WarnAfter := True;
    CheckEquals(True, FProjectOps.WarnAfter, 'WarnAfter Second Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(True, FProjectOps.WarnAfter, 'WarnAfter on Reload');
  Finally
    FProjectOps.Free;
  End;
End;

Procedure TestTProjectOptions.TestWarnBefore;

Var
  FProjectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(True, FProjectOps.WarnBefore, 'Default WarnBefore');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.WarnBefore := False;
    CheckEquals(False, FProjectOps.WarnBefore, 'WarnBefore First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(False, FProjectOps.WarnBefore, 'WarnBefore on Reload');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.WarnBefore := True;
    CheckEquals(True, FProjectOps.WarnBefore, 'WarnBefore Second Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals(True, FProjectOps.WarnBefore, 'WarnBefore on Reload');
  Finally
    FProjectOps.Free;
  End;
End;

Procedure TestTProjectOptions.TestZipName;

Var
  FPRojectOps : TProjectOptions;

Begin
  DeleteFile(GetProjectINIFileName);
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals('', FProjectOps.ZipName, 'Default ZipName');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.ZipName := 'D:\Path\MyZipFile.zip';
    CheckEquals('D:\Path\MyZipFile.zip', FProjectOps.ZipName, 'ZipName First Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals('D:\Path\MyZipFile.zip', FProjectOps.ZipName, 'ZipName on Reload');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    FProjectOps.ZipName := 'E:\MyPath\MyOtherZipFile.zip';
    CheckEquals('E:\MyPath\MyOtherZipFile.zip', FProjectOps.ZipName, 'ZipName Second Set');
  Finally
    FProjectOps.Free;
  End;
  FProjectOps := TProjectOptions.Create(GetProjectINIFileName, TProjectStub.Create);
  Try
    CheckEquals('E:\MyPath\MyOtherZipFile.zip', FProjectOps.ZipName, 'ZipName on Reload');
  Finally
    FProjectOps.Free;
  End;
End;
{$ENDREGION}

{$REGION 'TGlobalOptions Tests'}
//
// Test methods for the class TGlobalOptions.
//
Procedure TestTGlobalOptions.Setup;

Begin
End;

Procedure TestTGlobalOptions.TearDown;

Begin
End;

Procedure TestTGlobalOptions.TestProjectOptions;

Var
  FGOps : TGlobalOptions;
  P : TProjectOptions;

Begin
  DeleteFile(BuildRootKey(Nil, Nil));
  DeleteFile(GetProjectINIFileName);
  WriteINIFile(
    '[TestProjectOptionsProject.dpr.Setup]'#13#10 +
    'WarnBefore=1'#13#10 +
    'WarnAfter=1'#13#10 +
    'IncBuild=1'#13#10 +
    'CopyVersionInfoFrom=D:\HoylD\Borland Studio Projects\IDE Addins\BrowseAndDocIt\Test\BrowseAndDocItTests2010.exe'#13#10 +
    'ExcludedResExts=.dcr'#13#10 +
    ''#13#10 +
    '[TestProjectOptionsProject.dpr.Zipping]'#13#10 +
    'Enabled=0'#13#10 +
    'ZipFile=D:\HoylD\Web Page\Zips\browseanddocit.zip'#13#10 +
    'BasePath=D:\HoylD\Borland Studio Projects\'#13#10 +
    ''#13#10 +
    '[TestProjectOptionsProject.dpr.Additional Zip Files]'#13#10 +
    'Item0=D:\HoylD\Borland Studio Projects\Applications\Alignment Thingy\Help\*.rtf'#13#10 +
    'Item1=D:\HoylD\Borland Studio Projects\Applications\Alignment Thingy\Help\*.hpj'#13#10 +
    'Item2=D:\HoylD\Borland Studio Projects\Applications\Alignment Thingy\Help\Images\*.bmp'#13#10 +
    'Item3=D:\HoylD\Borland Studio Projects\Applications\Alignment Thingy\*.cnt'#13#10 +
    'Item4=D:\HoylD\Borland Studio Projects\Applications\Alignment Thingy\*.hlp'#13#10 +
    ''#13#10,
    BuildRootKey(Nil, Nil)
  );
  FGOPs := TGlobalOptions.Create;
  Try
    P := FGOps.ProjectOptions(TProjectStub.Create);
    CheckEquals(True, P.WarnBefore, 'WB');
    CheckEquals(True, P.WarnAfter, 'WA');
    CheckEquals(True, P.IncOnCompile, 'IOC');
    CheckEquals('D:\HoylD\Borland Studio Projects\IDE Addins\BrowseAndDocIt\Test\BrowseAndDocItTests2010.exe', P.CopyVerInfo);
    CheckEquals('.dcr', P.ResExtExc);
    CheckEquals(False, P.EnableZipping);
    CheckEquals('D:\HoylD\Web Page\Zips\browseanddocit.zip', P.ZipName);
    CheckEquals('D:\HoylD\Borland Studio Projects\', P.BasePath);
    CheckEquals(5, P.AddZipFiles.Count);
  Finally
    FGOps.free;
  End;
  FGOPs := TGlobalOptions.Create;
  Try
    P := FGOps.ProjectOptions(TProjectStub.Create);
    CheckEquals(True, P.WarnBefore);
    CheckEquals(True, P.WarnAfter);
    CheckEquals(True, P.IncOnCompile);
    CheckEquals('D:\HoylD\Borland Studio Projects\IDE Addins\BrowseAndDocIt\Test\BrowseAndDocItTests2010.exe', P.CopyVerInfo);
    CheckEquals('.dcr', P.ResExtExc);
    CheckEquals(False, P.EnableZipping);
    CheckEquals('D:\HoylD\Web Page\Zips\browseanddocit.zip', P.ZipName);
    CheckEquals('D:\HoylD\Borland Studio Projects\', P.BasePath);
    CheckEquals(5, P.AddZipFiles.Count);
  Finally
    FGOps.free;
  End;
  DeleteFile(BuildRootKey(Nil, Nil));
  DeleteFile(GetProjectINIFileName);
  WriteINIFile(
    '[TestProjectOptionsProject.dpr.Setup]'#13#10 +
    'WarnBefore=0'#13#10 +
    'WarnAfter=0'#13#10 +
    'IncBuild=0'#13#10 +
    'CopyVersionInfoFrom=D:\HoylD\IDE Addins\BrowseAndDocIt\Test\BrowseAndDocItTests2010.exe'#13#10 +
    'ExcludedResExts=.dcr;.res'#13#10 +
    ''#13#10 +
    '[TestProjectOptionsProject.dpr.Zipping]'#13#10 +
    'Enabled=1'#13#10 +
    'ZipFile=E:\HoylD\Web Page\Zips\browseanddocit.zip'#13#10 +
    'BasePath=E:\HoylD\Borland Studio Projects\'#13#10 +
    ''#13#10 +
    '[TestProjectOptionsProject.dpr.Additional Zip Files]'#13#10 +
    'Item0=E:\HoylD\Borland Studio Projects\Applications\Alignment Thingy\Help\*.rtf'#13#10 +
    'Item1=E:\HoylD\Borland Studio Projects\Applications\Alignment Thingy\Help\*.hpj'#13#10 +
    'Item2=E:\HoylD\Borland Studio Projects\Applications\Alignment Thingy\Help\Images\*.bmp'#13#10 +
    'Item3=E:\HoylD\Borland Studio Projects\Applications\Alignment Thingy\*.cnt'#13#10 +
    ''#13#10,
    BuildRootKey(Nil, Nil)
  );
  FGOPs := TGlobalOptions.Create;
  Try
    P := FGOps.ProjectOptions(TProjectStub.Create);
    CheckEquals(False, P.WarnBefore, 'WB');
    CheckEquals(False, P.WarnAfter, 'WA');
    CheckEquals(False, P.IncOnCompile, 'IOC');
    CheckEquals('D:\HoylD\IDE Addins\BrowseAndDocIt\Test\BrowseAndDocItTests2010.exe', P.CopyVerInfo);
    CheckEquals('.dcr;.res', P.ResExtExc);
    CheckEquals(True, P.EnableZipping);
    CheckEquals('E:\HoylD\Web Page\Zips\browseanddocit.zip', P.ZipName);
    CheckEquals('E:\HoylD\Borland Studio Projects\', P.BasePath);
    CheckEquals(4, P.AddZipFiles.Count);
  Finally
    FGOps.free;
  End;
End;

Procedure TestTGlobalOptions.TestSave;

Var
  FGOps: TGlobalOptions;

Begin
  DeleteFile(BuildRootKey(Nil, Nil));
  CheckEquals(False, FileExists(BuildRootKey(Nil, Nil)));
  FGOps := TGlobalOptions.Create;
  Try
    CheckEquals(False, FileExists(BuildRootKey(Nil, Nil)));
    FGops.Save;
    CheckEquals(True, FileExists(BuildRootKey(Nil, Nil)));
  Finally
    FGOPs.Free;
  End;
End;

Procedure TestTGlobalOptions.TestAutoScrollMessages;

Var
  GOps : TGlobalOptions;

Begin
   DeleteFile(BuildRootKey(Nil, Nil));
   GOps := TGlobalOptions.Create;
   Try
     CheckEquals(True, GOps.AutoScrollMessages);
     GOps.AutoScrollMessages := False;
     CheckEquals(False, GOps.AutoScrollMessages);
   Finally
     GOps.Free;
   End;
   GOps := TGlobalOptions.Create;
   Try
     CheckEquals(False, GOps.AutoScrollMessages);
     GOps.AutoScrollMessages := True;
     CheckEquals(True, GOps.AutoScrollMessages);
   Finally
     GOps.Free;
   End;
   GOps := TGlobalOptions.Create;
   Try
     CheckEquals(True, GOps.AutoScrollMessages);
   Finally
     GOps.Free;
   End;
End;

Procedure TestTGlobalOptions.TestClearMessages;

Var
  GOps : TGlobalOptions;

Begin
  DeleteFile(BuildRootKey(Nil, Nil));
  GOPs := TGlobalOptions.Create;
  Try
    CheckEquals(30, GOps.ClearMessages);
    GOps.ClearMessages := 60;
    CheckEquals(60, GOps.ClearMessages);
  Finally
    GOps.Free;
  End;
  GOPs := TGlobalOptions.Create;
  Try
    CheckEquals(60, GOps.ClearMessages);
    GOps.ClearMessages := 45;
    CheckEquals(45, GOps.ClearMessages);
  Finally
    GOps.Free;
  End;
  GOPs := TGlobalOptions.Create;
  Try
    CheckEquals(45, GOps.ClearMessages);
  Finally
    GOps.Free;
  End;
End;

Procedure TestTGlobalOptions.TestFontColour;

Var
  FGOPs : TGlobalOptions;

Begin
  DeleteFile(BuildRootKey(Nil, Nil));
  FGOps := TGlobalOptions.Create;
  Try
    CheckEquals(clBlack, FGOps.FontColour[ithfDefault]);
    CheckEquals(clBlack, FGOps.FontColour[ithfFailure]);
    CheckEquals(clBlack, FGOps.FontColour[ithfHeader]);
    CheckEquals(clBlack, FGOps.FontColour[ithfSuccess]);
    CheckEquals(clBlack, FGOps.FontColour[ithfWarning]);
    FGOps.FontColour[ithfDefault] := clRed;
    FGOps.FontColour[ithfFailure] := clGreen;
    FGOps.FontColour[ithfHeader]  := clBlue;
    FGOps.FontColour[ithfSuccess] := clPurple;
    FGOps.FontColour[ithfWarning] := clYellow;
    CheckEquals(clRed, FGOps.FontColour[ithfDefault]);
    CheckEquals(clGreen, FGOps.FontColour[ithfFailure]);
    CheckEquals(clBlue, FGOps.FontColour[ithfHeader]);
    CheckEquals(clPurple, FGOps.FontColour[ithfSuccess]);
    CheckEquals(clYellow, FGOps.FontColour[ithfWarning]);
  Finally
    FGOps.Free;
  End;
  FGOps := TGlobalOptions.Create;
  Try
    CheckEquals(clRed, FGOps.FontColour[ithfDefault]);
    CheckEquals(clGreen, FGOps.FontColour[ithfFailure]);
    CheckEquals(clBlue, FGOps.FontColour[ithfHeader]);
    CheckEquals(clPurple, FGOps.FontColour[ithfSuccess]);
    CheckEquals(clYellow, FGOps.FontColour[ithfWarning]);
    FGOps.FontColour[ithfDefault] := clFuchsia;
    FGOps.FontColour[ithfFailure] := clLime;
    FGOps.FontColour[ithfHeader]  := clMaroon;
    FGOps.FontColour[ithfSuccess] := clNavy;
    FGOps.FontColour[ithfWarning] := clTeal;
    CheckEquals(clFuchsia, FGOps.FontColour[ithfDefault]);
    CheckEquals(clLime, FGOps.FontColour[ithfFailure]);
    CheckEquals(clMaroon, FGOps.FontColour[ithfHeader]);
    CheckEquals(clNavy, FGOps.FontColour[ithfSuccess]);
    CheckEquals(clTeal, FGOps.FontColour[ithfWarning]);
  Finally
    FGOps.Free;
  End;
  FGOps := TGlobalOptions.Create;
  Try
    CheckEquals(clFuchsia, FGOps.FontColour[ithfDefault]);
    CheckEquals(clLime, FGOps.FontColour[ithfFailure]);
    CheckEquals(clMaroon, FGOps.FontColour[ithfHeader]);
    CheckEquals(clNavy, FGOps.FontColour[ithfSuccess]);
    CheckEquals(clTeal, FGOps.FontColour[ithfWarning]);
  Finally
    FGOps.Free;
  End;
End;

Procedure TestTGlobalOptions.TestFontName;

Var
  FGOPs : TGlobalOptions;

Begin
  DeleteFile(BuildRootKey(Nil, Nil));
  FGOps := TGlobalOptions.Create;
  Try
    CheckEquals('Tahoma', FGOps.FontName[fnHeader]);
    CheckEquals('Tahoma', FGOps.FontName[fnTools]);
    FGOps.FontName[fnHeader] := 'Arial';
    FGOps.FontName[fnTools] := 'Times New Roman';
    CheckEquals('Arial', FGOps.FontName[fnHeader]);
    CheckEquals('Times New Roman', FGOps.FontName[fnTools]);
  Finally
    FGOps.Free;
  End;
  FGOps := TGlobalOptions.Create;
  Try
    CheckEquals('Arial', FGOps.FontName[fnHeader]);
    CheckEquals('Times New Roman', FGOps.FontName[fnTools]);
    FGOps.FontName[fnHeader] := 'Courier';
    FGOps.FontName[fnTools] := 'Courier New';
    CheckEquals('Courier', FGOps.FontName[fnHeader]);
    CheckEquals('Courier New', FGOps.FontName[fnTools]);
  Finally
    FGOps.Free;
  End;
  FGOps := TGlobalOptions.Create;
  Try
    CheckEquals('Courier', FGOps.FontName[fnHeader]);
    CheckEquals('Courier New', FGOps.FontName[fnTools]);
  Finally
    FGOps.Free;
  End;
End;

Procedure TestTGlobalOptions.TestFontStyles;

Var
  FGOps : TGlobalOptions;
  Ops : TFontStyles;

Begin
  DeleteFile(BuildRootKey(Nil, Nil));
  FGOps := TGlobalOptions.Create;
  Try
    CheckEquals(0, Byte(FGOps.FontStyles[ithfDefault]));
    CheckEquals(0, Byte(FGOps.FontStyles[ithfFailure]));
    CheckEquals(0, Byte(FGOps.FontStyles[ithfHeader]));
    CheckEquals(0, Byte(FGOps.FontStyles[ithfSuccess]));
    CheckEquals(0, Byte(FGOps.FontStyles[ithfWarning]));
    FGOps.FontStyles[ithfDefault] := [fsBold];
    FGOps.FontStyles[ithfFailure] := [fsItalic];
    FGOps.FontStyles[ithfHeader]  := [fsUnderline];
    FGOps.FontStyles[ithfSuccess] := [fsStrikeout];
    FGOps.FontStyles[ithfWarning] := [fsBold];
    Ops := [fsBold];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfDefault]));
    Ops := [fsItalic];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfFailure]));
    Ops := [fsUnderline];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfHeader]));
    Ops := [fsStrikeOut];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfSuccess]));
    Ops := [fsBold];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfWarning]));
  Finally
    FGOps.Free;
  End;
  FGOps := TGlobalOptions.Create;
  Try
    Ops := [fsBold];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfDefault]));
    Ops := [fsItalic];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfFailure]));
    Ops := [fsUnderline];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfHeader]));
    Ops := [fsStrikeOut];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfSuccess]));
    Ops := [fsBold];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfWarning]));
    FGOps.FontStyles[ithfDefault] := [fsItalic, fsUnderline];
    FGOps.FontStyles[ithfFailure] := [fsUnderline, fsStrikeOut];
    FGOps.FontStyles[ithfHeader]  := [fsStrikeOut, fsBold];
    FGOps.FontStyles[ithfSuccess] := [fsBold, fsItalic];
    FGOps.FontStyles[ithfWarning] := [fsItalic, fsUnderline];
    Ops := [fsItalic, fsUnderline];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfDefault]));
    Ops := [fsUnderline, fsStrikeout];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfFailure]));
    Ops := [fsStrikeOut, fsBold];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfHeader]));
    Ops := [fsBold, fsItalic];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfSuccess]));
    Ops := [fsItalic, fsUnderline];
  Finally
    FGOps.Free;
  End;
  FGOps := TGlobalOptions.Create;
  Try
    Ops := [fsItalic, fsUnderline];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfDefault]));
    Ops := [fsUnderline, fsStrikeout];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfFailure]));
    Ops := [fsStrikeOut, fsBold];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfHeader]));
    Ops := [fsBold, fsItalic];
    CheckEquals(Byte(Ops), Byte(FGOps.FontStyles[ithfSuccess]));
    Ops := [fsItalic, fsUnderline];
  Finally
    FGOps.Free;
  End;
End;

Procedure TestTGlobalOptions.TestGroupMessages;

Var
  GOps : TGlobalOptions;

Begin
  DeleteFile(BuildRootKey(Nil, Nil));
  GOps := TGlobalOptions.Create;
  Try
    CheckEquals(False, GOps.GroupMessages);
    GOps.GroupMessages := True;
    CheckEquals(True, GOps.GroupMessages);
  Finally
    GOps.Free;
  End;
  GOps := TGlobalOptions.Create;
  Try
    CheckEquals(True, GOps.GroupMessages);
    GOps.GroupMessages := False;
    CheckEquals(False, GOps.GroupMessages);
  Finally
    GOps.Free;
  End;
  GOps := TGlobalOptions.Create;
  Try
    CheckEquals(False, GOps.GroupMessages);
  Finally
    GOps.Free;
  End;
End;

Procedure TestTGlobalOptions.TestINIFileName;

Var
  GOps : TGlobalOptions;

Begin
  DeleteFile(BuildRootKey(Nil, Nil));
  GOps := TGlobalOptions.Create;
  Try
    CheckEquals(BuildRootKey(Nil, Nil), Gops.INIFileName);
  Finally
    GOps.Free;
  End;
End;

Procedure TestTGlobalOptions.TestProjectGroupOps_NewProject;

Var
  FGOps : TGlobalOptions;
  Ops : TEnabledOptions;

Begin
  DeleteFile(BuildRootKey(Nil, Nil));
  DeleteFile(GetProjectINIFileName);
  FGOPs := TGlobalOptions.Create;
  Try
    Ops := [eoBefore..eoIncrementBuild];
    CheckEquals(Byte(Ops), Byte(FGOPs.ProjectGroupOps));
    FGOps.ProjectGroupOps := [eoBefore, eoZip, eoCopyVersionInfo, eoIncrementBuild];
    Ops := [eoBefore, eoZip, eoCopyVersionInfo, eoIncrementBuild];
    CheckEquals(Byte(Ops), Byte(FGOPs.ProjectGroupOps));
  Finally
    FGOps.free;
  End;
  FGOPs := TGlobalOptions.Create;
  Try
    Ops := [eoBefore, eoZip, eoCopyVersionInfo, eoIncrementBuild];
    CheckEquals(Byte(Ops), Byte(FGOPs.ProjectGroupOps));
    FGOps.ProjectGroupOps := [eoAfter, eoBuildVersionResource, eoGroupEnabled];
    Ops := [eoAfter, eoBuildVersionResource, eoGroupEnabled];
    CheckEquals(Byte(Ops), Byte(FGOPs.ProjectGroupOps));
  Finally
    FGOps.free;
  End;
  FGOPs := TGlobalOptions.Create;
  Try
    Ops := [eoAfter, eoBuildVersionResource, eoGroupEnabled];
    CheckEquals(Byte(Ops), Byte(FGOPs.ProjectGroupOps));
  Finally
    FGOps.free;
  End;
End;

Procedure TestTGlobalOptions.TestProjectGroupOps_OldProject;

Var
  FGOps : TGlobalOptions;
  Ops : TEnabledOptions;

Begin
  DeleteFile(BuildRootKey(Nil, Nil));
  DeleteFile(GetProjectINIFileName);
  Ops := [eoAfter];
  WriteINIFile(
    '[ProjectGroupOptions]'#13#10 +
    'TestGlobalOptionsGroup.groupproj=' + IntToStr(Byte(Ops)),
    BuildRootKey(Nil, Nil)
  );
  FGOPs := TGlobalOptions.Create;
  Try
    Ops := [eoAfter, eoBuildVersionResource, eoCopyVersionInfo, eoIncrementBuild];
    CheckEquals(Byte(Ops), Byte(FGOPs.ProjectGroupOps));
    FGOps.ProjectGroupOps := [eoBefore, eoZip, eoCopyVersionInfo, eoIncrementBuild];
    Ops := [eoBefore, eoZip, eoCopyVersionInfo, eoIncrementBuild];
    CheckEquals(Byte(Ops), Byte(FGOPs.ProjectGroupOps));
  Finally
    FGOps.free;
  End;
  FGOPs := TGlobalOptions.Create;
  Try
    Ops := [eoBefore, eoZip, eoCopyVersionInfo, eoIncrementBuild];
    CheckEquals(Byte(Ops), Byte(FGOPs.ProjectGroupOps));
  Finally
    FGOps.free;
  End;
  // Update VERY OLD Project
  DeleteFile(BuildRootKey(Nil, Nil));
  DeleteFile(GetProjectINIFileName);
  Ops := [eoAfter, eoBefore];
  WriteINIFile(
    '[TestGlobalOptionsGroup.groupproj.Setup]'#13#10 +
    'Enabled=0'#13#10 +
    'EnabledOptions=' + IntToStr(Byte(Ops)),
    BuildRootKey(Nil, Nil)
  );
  FGOPs := TGlobalOptions.Create;
  Try
    Ops := [eoAfter, eoBefore, eoBuildVersionResource, eoCopyVersionInfo, eoIncrementBuild];
    CheckEquals(Byte(Ops), Byte(FGOPs.ProjectGroupOps));
    FGOps.ProjectGroupOps := [eoBefore, eoZip, eoCopyVersionInfo, eoIncrementBuild];
    Ops := [eoBefore, eoZip, eoCopyVersionInfo, eoIncrementBuild];
    CheckEquals(Byte(Ops), Byte(FGOPs.ProjectGroupOps));
  Finally
    FGOps.free;
  End;
  FGOPs := TGlobalOptions.Create;
  Try
    Ops := [eoBefore, eoZip, eoCopyVersionInfo, eoIncrementBuild];
    CheckEquals(Byte(Ops), Byte(FGOPs.ProjectGroupOps));
  Finally
    FGOps.free;
  End;
  // Update VERY OLD Project
  DeleteFile(BuildRootKey(Nil, Nil));
  DeleteFile(GetProjectINIFileName);
  Ops := [eoBefore];
  WriteINIFile(
    '[TestGlobalOptionsGroup.groupproj.Setup]'#13#10 +
    'Enabled=1'#13#10 +
    'EnabledOptions=' + IntToStr(Byte(Ops)),
    BuildRootKey(Nil, Nil)
  );
  FGOPs := TGlobalOptions.Create;
  Try
    Ops := [eoBefore, eoGroupEnabled, eoBuildVersionResource, eoCopyVersionInfo, eoIncrementBuild];
    CheckEquals(Byte(Ops), Byte(FGOPs.ProjectGroupOps));
    FGOps.ProjectGroupOps := [eoBefore, eoZip, eoCopyVersionInfo, eoIncrementBuild];
    Ops := [eoBefore, eoZip, eoCopyVersionInfo, eoIncrementBuild];
    CheckEquals(Byte(Ops), Byte(FGOPs.ProjectGroupOps));
  Finally
    FGOps.free;
  End;
  FGOPs := TGlobalOptions.Create;
  Try
    Ops := [eoBefore, eoZip, eoCopyVersionInfo, eoIncrementBuild];
    CheckEquals(Byte(Ops), Byte(FGOPs.ProjectGroupOps));
  Finally
    FGOps.free;
  End;
End;

Procedure TestTGlobalOptions.TestSwitchToMessages;

Var
  GOps : TGlobalOptions;

Begin
  DeleteFile(BuildRootKey(Nil, Nil));
  GOps := TGlobalOptions.Create;
  Try
    CheckEquals(True, GOps.SwitchToMessages);
    GOps.SwitchToMessages := False;
    CheckEquals(False, GOps.SwitchToMessages);
  Finally
    GOps.Free;
  End;
  GOps := TGlobalOptions.Create;
  Try
    CheckEquals(False, GOps.SwitchToMessages);
    GOps.SwitchToMessages := True;
    CheckEquals(True, GOps.SwitchToMessages);
  Finally
    GOps.Free;
  End;
  GOps := TGlobalOptions.Create;
  Try
    CheckEquals(True, GOps.SwitchToMessages);
  Finally
    GOps.Free;
  End;
End;

Procedure TestTGlobalOptions.TestZipEXE;

Var
  GOps : TGlobalOptions;

Begin
  DeleteFile(BuildRootKey(Nil, Nil));
  GOps := TGlobalOptions.Create;
  Try
    CheckEquals('C:\Program Files\WinZip\WZZip.EXE', GOps.ZipEXE);
    GOps.ZipEXE := 'C:\Program Files (x86)\WinZip\WZZip.exe';
    CheckEquals('C:\Program Files (x86)\WinZip\WZZip.exe', GOps.ZipEXE);
  Finally
    GOps.Free;
  End;
  GOps := TGlobalOptions.Create;
  Try
    CheckEquals('C:\Program Files (x86)\WinZip\WZZip.exe', GOps.ZipEXE);
    GOps.ZipEXE := 'C:\Program Files\WinZip\WZZip.exe';
    CheckEquals('C:\Program Files\WinZip\WZZip.exe', GOps.ZipEXE);
  Finally
    GOps.Free;
  End;
  GOps := TGlobalOptions.Create;
  Try
    CheckEquals('C:\Program Files\WinZip\WZZip.exe', GOps.ZipEXE);
  Finally
    GOps.Free;
  End;
End;

Procedure TestTGlobalOptions.TestZipParameters;

Var
  GOps : TGlobalOptions;

Begin
  DeleteFile(BuildRootKey(Nil, Nil));
  GOps := TGlobalOptions.Create;
  Try
    CheckEquals('-ouexrPyb @"$RESPONSEFILE$" "$ZIPFILE$"', GOps.ZipParameters);
    GOps.ZipParameters := '-exrp @"$RESPONSEFILE$" "$ZIPFILE$"';
    CheckEquals('-exrp @"$RESPONSEFILE$" "$ZIPFILE$"', GOps.ZipParameters);
  Finally
    GOps.Free;
  End;
  GOps := TGlobalOptions.Create;
  Try
    CheckEquals('-exrp @"$RESPONSEFILE$" "$ZIPFILE$"', GOps.ZipParameters);
    GOps.ZipParameters := '-ouexrp @"$RESPONSEFILE$" "$ZIPFILE$"';
    CheckEquals('-ouexrp @"$RESPONSEFILE$" "$ZIPFILE$"', GOps.ZipParameters);
  Finally
    GOps.Free;
  End;
  GOps := TGlobalOptions.Create;
  Try
    CheckEquals('-ouexrp @"$RESPONSEFILE$" "$ZIPFILE$"', GOps.ZipParameters);
  Finally
    GOps.Free;
  End;
End;
{$ENDREGION}

Initialization
  RegisterTest('Project Options Adapter', TestTProjectOptions.Suite);
  RegisterTest('Global Options Adapter', TestTGlobalOptions.Suite);
End.