(**

  This modules contains a form for specifying the EXE, Params and Working
  Directory for external tools.

  @Version 1.0
  @Author  David Hoyle
  @Date    04 Jun 2012

**)
unit ProgrammeInfoForm;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, Buttons, StdCtrls, ExtCtrls;

{$INCLUDE 'CompilerDefinitions.inc'}

type
  (** An enumerate for the starting window state of the application. **)
  TStartingWindowState = (
    swsDisabled = 0,
    swsNormal = SW_NORMAL,
    swsMinimised = SW_SHOWMINIMIZED,
    swsMaximised = SW_SHOWMAXIMIZED
  );

  (** A class to represent the form. **)
  TfrmProgrammeInfo = class(TForm)
    lblProgramme: TLabel;
    edtProgramme: TEdit;
    lblParameters: TLabel;
    edtParameters: TEdit;
    lblWorkingDirectrory: TLabel;
    edtWorkingDirectory: TEdit;
    btnEXE: TButton;
    btnDirectory: TButton;
    btnOK: TBitBtn;
    btnCancel: TBitBtn;
    dlgOpen: TOpenDialog;
    rgpStartingWindowState: TRadioGroup;
    edtTitle: TEdit;
    lblTitle: TLabel;
    procedure btnEXEClick(Sender: TObject);
    procedure btnDirectoryClick(Sender: TObject);
  private
    { Private declarations }
    Procedure LoadPosition(strINIFile : String);
    Procedure SavePosition(strINIFile : String);
  public
    { Public declarations }
    Class Function Execute(var strTitle, strEXE, strParam, strDir : String;
      strINIFile : String; var State : TStartingWindowState) : Boolean;
  end;

implementation

{$R *.dfm}

Uses
  FileCtrl, INIFiles;

(**

  This is an on click event handler for the Directory browse button.

  @precon  None.
  @postcon Allows the user to browse for a directory.

  @param   Sender as a TObject

**)
procedure TfrmProgrammeInfo.btnDirectoryClick(Sender: TObject);

Var
  strDirectory : String;

begin
  strDirectory := edtWorkingDirectory.Text;
  If strDirectory = '' Then
    strDirectory := ExtractFilePath(edtProgramme.Text);
  If SelectDirectory('Select a Working Directory', '', strDirectory {$IFDEF D2005},
    [sdNewFolder, sdShowShares, sdNewUI, sdValidateDir] {$ENDIF} ) Then
    edtWorkingDirectory.Text := strDirectory + '\';
end;

(**

  This is an on click event handler for the EXE browse button.

  @precon  None.
  @postcon Allows the user to browse for EXE, BAT anmd BTM files.

  @param   Sender as a TObject

**)
procedure TfrmProgrammeInfo.btnEXEClick(Sender: TObject);
begin
  With dlgOpen Do
    If Execute Then
      Begin
        edtProgramme.Text := Filename;
        If edtWorkingDirectory.Text = '' Then
          edtWorkingDirectory.Text := ExtractFilePath(FileName);
      End;
end;

(**

  This is the classes interface Singleton method. If the dialogue is confirmed the
  information is returned in the var parameters.

  @precon  None.
  @postcon If the dialogue is confirmed the information is returned in the var parameters
           .

  @param   strTitle   as a String as a reference
  @param   strEXE     as a String as a reference
  @param   strParam   as a String as a reference
  @param   strDir     as a String as a reference
  @param   strINIFile as a String
  @param   State      as a TStartingWindowState as a reference
  @return  a Boolean

**)
class function TfrmProgrammeInfo.Execute(var strTitle, strEXE, strParam,
  strDir : String; strINIFile: String; var State : TStartingWindowState): Boolean;

begin
  With TfrmProgrammeInfo.Create(Nil) Do
    Try
      Result := False;
      edtTitle.Text := strTitle;
      edtProgramme.Text := strEXE;
      edtParameters.Text := strParam;
      edtWorkingDirectory.Text := strDir;
      Case State Of
        swsNormal   : rgpStartingWindowState.ItemIndex := 0;
        swsMinimised: rgpStartingWindowState.ItemIndex := 1;
        swsMaximised: rgpStartingWindowState.ItemIndex := 2;
      Else
        rgpStartingWindowState.Enabled := False;
      End;
      LoadPosition(strINIFile);
      If ShowModal = mrOK Then
        Begin
          strTitle := edtTitle.Text;
          strEXE := edtProgramme.Text;
          strParam := edtParameters.Text;
          strDir := edtWorkingDirectory.Text;
          Case rgpStartingWindowState.ItemIndex Of
            1: State := swsMinimised;
            2: State := swsMaximised;
          Else
            State := swsNormal;
          End;
          SavePosition(strINIFile);
          Result := True;
        End;
    Finally
      Free;
    End;
end;

(**

  This method loads the position of the dialogue from the pased INI File.

  @precon  None.
  @postcon Loads the position of the dialogue from the pased INI File.

  @param   strINIFile as a String

**)
procedure TfrmProgrammeInfo.LoadPosition(strINIFile: String);
begin
  With TMemIniFile.Create(strINIFile) Do
    Try
      Top := ReadInteger('ProgrammeInfoDlg', 'Top',
        Application.MainForm.Top + Application.MainForm.Height Div 2 - Height Div 2);
      Left := ReadInteger('ProgrammeInfoDlg', 'Left',
        Application.MainForm.Left + Application.MainForm.Width Div 2 - Width Div 2);
      Height := ReadInteger('ProgrammeInfoDlg', 'Height', Height);
      Width := ReadInteger('ProgrammeInfoDlg', 'Width', Width);
    Finally
      Free;
    End;
end;

(**

  This method saves the position of the dialogue to the passed INI file.

  @precon  None.
  @postcon Saves the position of the dialogue to the passed INI file.

  @param   strINIFile as a String

**)
procedure TfrmProgrammeInfo.SavePosition(strINIFile: String);
begin
  With TMemIniFile.Create(strINIFile) Do
    Try
      WriteInteger('ProgrammeInfoDlg', 'Top', Top);
      WriteInteger('ProgrammeInfoDlg', 'Left', Left);
      WriteInteger('ProgrammeInfoDlg', 'Height', Height);
      WriteInteger('ProgrammeInfoDlg', 'Width', Width);
      UpdateFile;
    Finally
      Free;
    End;
end;

end.

